@@ -29,46 +29,46 @@
 #include <QObject>
 #include <QPersistentModelIndex>
 #include <QScopedPointer>
+#include <QItemSelectionModel>
 #include "frame.h"
+#include "framelist.h"
+#include "fileproxymodel.h"
+#include "dirproxymodel.h"
+#include "frametablemodel.h"
+#include "genremodel.h"
+#include "downloadclient.h"
+#include "batchimporter.h"
+#include "dirrenamer.h"
+#include "frameeditorobject.h"
+#include "taggedfileselection.h"
 #include "trackdata.h"
 #include "tagsearcher.h"
 #include "generalconfig.h"
 #include "config.h"
 
-class QItemSelectionModel;
 class QItemSelection;
 class QModelIndex;
 class QNetworkAccessManager;
 class QDir;
 class QUrl;
 class FileSystemModel;
-class FileProxyModel;
 class FileProxyModelIterator;
-class DirProxyModel;
 class TrackDataModel;
-class GenreModel;
-class FrameTableModel;
-class TaggedFileSelection;
 class ConfigStore;
 class PlaylistConfig;
 class PlaylistModel;
-class DownloadClient;
 class TaggedFile;
-class FrameList;
 class IFrameEditor;
 class ServerImporter;
 class ServerTrackImporter;
 class ITaggedFileFactory;
 class TextExporter;
-class DirRenamer;
 class BatchImportProfile;
-class BatchImporter;
 class Kid3ApplicationTagContext;
 class IAbortable;
 class ICorePlatformTools;
 class IUserCommandProcessor;
 class ImageDataProvider;
-class FrameEditorObject;
 class FileFilter;
 
 /**
